import type { Equatable } from "@siteimprove/alfa-equatable";
import type { Serializable } from "@siteimprove/alfa-json";
import type * as json from "@siteimprove/alfa-json";
import type { Parser as CSSParser } from "./parser.js";
import { Token } from "./token.js";
/**
 * {@link https://drafts.csswg.org/css-syntax/#simple-block}
 *
 * @public
 */
export declare class Block implements Iterable<Token>, Equatable, Serializable {
    static of(token: Block.Open, value: Iterable<Token>): Block;
    private readonly _token;
    private readonly _value;
    private constructor();
    get token(): Block.Open;
    get value(): Array<Token>;
    [Symbol.iterator](): Iterator<Token>;
    equals(value: unknown): value is this;
    toJSON(): Block.JSON;
    toString(): string;
}
/**
 * @public
 */
export declare namespace Block {
    interface JSON {
        [key: string]: json.JSON;
        token: Token.JSON;
        value: Array<Token.JSON>;
    }
    /**
     * The tokens that are allowed to open a block.
     */
    type Open = Token.OpenParenthesis | Token.OpenSquareBracket | Token.OpenCurlyBracket;
    /**
     * The tokens that are allowed to close a block.
     */
    type Close = Token.CloseParenthesis | Token.CloseSquareBracket | Token.CloseCurlyBracket;
    /**
     * {@link https://drafts.csswg.org/css-syntax/#consume-a-simple-block}
     */
    const consume: CSSParser<Block>;
}
//# sourceMappingURL=block.d.ts.map