/**
 * @public
 */
export type Unit = Unit.Length | Unit.Angle | Unit.Time | Unit.Frequency | Unit.Resolution;
/**
 * @public
 */
export declare namespace Unit {
    namespace Length {
        /**
         * {@link https://drafts.csswg.org/css-values/#relative-lengths}
         */
        type Relative = Relative.Font | Relative.Viewport;
        namespace Relative {
            /**
             * {@link https://drafts.csswg.org/css-values/#font-relative-lengths}
             */
            type Font = "em" | "ex" | "ch" | "rem";
            /**
             * {@link https://drafts.csswg.org/css-values/#viewport-relative-lengths}
             */
            type Viewport = "vw" | "vh" | "vmin" | "vmax";
        }
        function isRelative(unit: string): unit is Relative;
        function isFontRelative(unit: string): unit is Relative.Font;
        function isViewportRelative(unit: string): unit is Relative.Viewport;
        /**
         * {@link https://drafts.csswg.org/css-values/#lengths}
         */
        const Canonical = "px";
        type Canonical = typeof Canonical;
        function isCanonical(unit: string): unit is Canonical;
        /**
         * {@link https://drafts.csswg.org/css-values/#absolute-lengths}
         */
        type Absolute = "cm" | "mm" | "Q" | "in" | "pc" | "pt" | Canonical;
        function isAbsolute(unit: string): unit is Absolute;
    }
    const isRelativeLength: typeof Length.isRelative, isFontRelativeLength: typeof Length.isFontRelative, isViewportRelativeLength: typeof Length.isViewportRelative, isAbsoluteLength: typeof Length.isAbsolute;
    /**
     * {@link https://drafts.csswg.org/css-values/#lengths}
     */
    type Length = Length.Relative | Length.Absolute;
    function isLength(unit: string): unit is Length;
    namespace Angle {
        /**
         * {@link https://drafts.csswg.org/css-values/#angles}
         */
        const Canonical = "deg";
        type Canonical = typeof Canonical;
        function isCanonical(unit: string): unit is Canonical;
    }
    /**
     * {@link https://drafts.csswg.org/css-values/#angles}
     */
    type Angle = Angle.Canonical | "grad" | "rad" | "turn";
    function isAngle(unit: string): unit is Angle;
    namespace Time {
        /**
         * {@link https://drafts.csswg.org/css-values/#time}
         */
        const Canonical = "s";
        type Canonical = typeof Canonical;
        function isCanonical(unit: string): unit is Canonical;
    }
    /**
     * {@link https://drafts.csswg.org/css-values/#time}
     */
    type Time = Time.Canonical | "ms";
    function isTime(unit: string): unit is Time;
    namespace Frequency {
        /**
         * {@link https://drafts.csswg.org/css-values/#frequency}
         */
        const Canonical = "hz";
        type Canonical = typeof Canonical;
        function isCanonical(unit: string): unit is Canonical;
    }
    /**
     * {@link https://drafts.csswg.org/css-values/#frequency}
     */
    type Frequency = Frequency.Canonical | "kHz";
    function isFrequency(unit: string): unit is Frequency;
    namespace Resolution {
        /**
         * {@link https://drafts.csswg.org/css-values/#resolution}
         */
        const Canonical = "dppx";
        type Canonical = typeof Canonical;
        function isCanonical(unit: string): unit is Canonical;
    }
    /**
     * {@link https://drafts.csswg.org/css-values/#resolution}
     */
    type Resolution = "dpi" | "dpcm" | Resolution.Canonical;
    function isResolution(unit: string): unit is Resolution;
}
//# sourceMappingURL=unit.d.ts.map